Crate camel_bean

Crate camel_bean 

Bean component for rust-camel — register and invoke named beans as route processors.

Main types: BeanRegistry, BeanProcessor. Main modules: error, processor, registry.

Structs

BeanRegistry

Enums

BeanError

Traits

BeanProcessor

Attribute Macros

async_trait
bean_impl
Attribute macro for generating BeanProcessor implementation from an impl block
handler
Marker attribute for handler methods This attribute does not transform the method - it’s detected by the Bean derive macro to identify which methods should be exposed as bean handlers

Derive Macros

Bean