Bean component for rust-camel — register and invoke named beans as route processors.
Main types: BeanRegistry, BeanProcessor. Main modules: error, processor, registry.
Structs
Enums
Traits
Attribute Macros
- async_
trait - bean_
impl - Attribute macro for generating BeanProcessor implementation from an impl block
- handler
- Marker attribute for handler methods This attribute does not transform the method - it’s detected by the Bean derive macro to identify which methods should be exposed as bean handlers