#[handler]Expand description
Marker attribute for handler methods This attribute does not transform the method - it’s detected by the Bean derive macro to identify which methods should be exposed as bean handlers
#[handler]Marker attribute for handler methods This attribute does not transform the method - it’s detected by the Bean derive macro to identify which methods should be exposed as bean handlers